pub enum Def {
Result {
inst: Inst,
index: u8,
},
Param {
block: Block,
index: u32,
},
}Expand description
What defines a value.
Variants
Result
The result of an instruction, at this position among its results.
Param
A parameter of a block, at this position among its parameters.