RmwOp

Enum RmwOp 

pub enum RmwOp {
Show 13 variants Xchg, Add, Sub, And, Nand, Or, Xor, SMax, SMin, UMax, UMin, FAdd, FSub,
}
Which operation an atomic_rmw performs.

Variants



Xchg

Replace, returning the old value.



Add

Integer addition.



Sub

Integer subtraction.



And

Bitwise and.



Nand

Bitwise and, then complement, which is the one hardware sometimes has natively.



Or

Bitwise or.



Xor

Bitwise exclusive or.



SMax

Signed maximum.



SMin

Signed minimum.



UMax

Unsigned maximum.



UMin

Unsigned minimum.



FAdd

Floating point addition.



FSub

Floating point subtraction.

Implementations

Source

impl RmwOp

pub const fn name(self) -> &'static str

The textual form.

pub fn from_name(name: &str) -> Option<Self>

The operation with that name, if there is one.

pub fn all() -> impl Iterator<Item = Self>

Every operation.

pub const fn is_float(self) -> bool

Whether this operates on a floating point value rather than an integer.