parse

Function parse 

pub fn parse(text: &str, names: &mut Interner) -> Result<Module, ParseError>
Reads a module from the text the printer writes.

Names are interned into names, which is the same interner the printer will be given when the module is written back out.

Errors

Gives back the first thing in the text that does not add up, with the line it is on.