pub struct Counts {
pub values: usize,
pub insts: usize,
pub blocks: usize,
}Expand description
How many of each thing a function holds.
Fields
values: usizeValues, including the ones whose defining instruction has been removed.
insts: usizeInstructions, including the ones that have been removed from their block.
blocks: usizeBlocks.