ModuleCounts

Struct ModuleCounts 

pub struct ModuleCounts {
    pub funcs: usize,
    pub globals: usize,
    pub aliases: usize,
    pub metadata: usize,
    pub data_bytes: usize,
}
How much is in a module, from Module::counts.

Fields

funcs: usize

Functions, defined and declared.

globals: usize

Global variables, defined and declared.

aliases: usize

Aliases and ifuncs.

metadata: usize

Metadata nodes.

data_bytes: usize

Bytes in the byte pool, which is the bulk of what a module with large initializers weighs.