pub struct Reloc {
pub symbol: Symbol,
pub addend: i64,
pub size: u32,
}Expand description
The address of a symbol, written into a global’s image by the linker.
Fields
symbol: SymbolThe symbol whose address this is.
addend: i64What to add to that address. &array[2] is the address of array plus eight.
size: u32How many bytes the address occupies, which is the pointer width except where a target has a smaller relocation for it.