pub struct CallInfo {
pub callee: Option<Symbol>,
pub signature: Sig,
}Expand description
What a call needs beyond its arguments.
Fields
callee: Option<Symbol>The name, for a direct call. None for a call through an address, where the address is
the first operand.
signature: SigThe signature it is called with, which is where the ABI attributes are.