pub struct ModuleCounts {
pub funcs: usize,
pub globals: usize,
pub aliases: usize,
pub metadata: usize,
pub data_bytes: usize,
}Expand description
How much is in a module, from Module::counts.
Fields
funcs: usizeFunctions, defined and declared.
globals: usizeGlobal variables, defined and declared.
aliases: usizeAliases and ifuncs.
metadata: usizeMetadata nodes.
data_bytes: usizeBytes in the byte pool, which is the bulk of what a module with large initializers weighs.